#' @author Samuel I. Berchuck \email{sib2@duke.edu}
#'
#' @name spCP
#' @import Rcpp
#' @importFrom stats quantile rnorm runif median
#' @importFrom graphics abline axis layout par plot points polygon title segments symbols rect text lines
#' @importFrom grDevices col2rgb colorRampPalette
#' @importFrom utils tail
#' @importFrom stats dnorm lm sd var pnorm
#' @importFrom msm rtnorm
#' @importFrom mvtnorm pmvnorm
#' @useDynLib spCP
"_PACKAGE"
